@@ -1,5 +1,5 @@
 from .types import FormSpec, FormState, FormData, DjangoForm, JsonFormResponse, FormResponseAction
-from .fields import DumbInput, CaptchaInput
+from .widgets import DumbInput, CaptchaInput
 from .spec import get_form_spec
 from .forms import *
 from .form_helper import *
